@@ -14,6 +14,7 @@ import os
 import pathlib
 import re
 import types
+import typing
 from ast import literal_eval
 from collections import defaultdict
 from http.client import HTTPResponse
@@ -34,7 +35,7 @@ from urllib.error import HTTPError
 from urllib.parse import urlparse
 from urllib.request import Request, urlopen
 
-__version__ = "0.2.5"
+__version__ = "0.4.0"
 __author__ = "Md Nazrul Islam <email2nazrul@gmail.com>"
 __all__ = ["Configuration", "FHIRSpec", "download", "filename_from_response"]
 
@@ -45,6 +46,7 @@ class FHIR_RELEASES(str, enum.Enum):
 
     R5 = "R5"
     R4 = "R4"
+    R4B = "R4B"
     STU3 = "STU3"
 
 
@@ -66,6 +68,7 @@ FHIR_VERSIONS_MAP = {
     "3.0.2": FHIR_RELEASES.STU3,
     "4.0.0": FHIR_RELEASES.R4,
     "4.0.1": FHIR_RELEASES.R4,
+    "4.3.0": FHIR_RELEASES.R4B,
 }
 HTTP_URL = re.compile(r"^https?://", re.IGNORECASE)
 UNSUPPORTED_PROFILES = [r"SimpleQuantity"]
@@ -87,7 +90,9 @@ class Configuration:
     __storage__: DefaultDict[str, Any]
     __slots__ = ("__storage__", "_initialized")
 
-    def __init__(self, data_dict: Dict[str, Any], path_variables: List[str] = None):
+    def __init__(
+        self, data_dict: Dict[str, Any], path_variables: Optional[List[str]] = None
+    ):
         """ """
         object.__setattr__(self, "__storage__", defaultdict())
         object.__setattr__(self, "_initialized", False)
@@ -174,7 +179,7 @@ class Configuration:
 
         _add(data_dict.items())
 
-    def normalize_paths(self, path_variables: List[str] = None) -> None:
+    def normalize_paths(self, path_variables: Optional[List[str]] = None) -> None:
         """ """
         init_ = object.__getattribute__(self, "_initialized")
         if init_ is False:
@@ -290,21 +295,23 @@ class FHIRSpec:
 
     _finalized: bool
 
-    def __init__(self, settings: Configuration, src_directory: pathlib.Path = None):
+    def __init__(
+        self, settings: Configuration, src_directory: Optional[pathlib.Path] = None
+    ):
         """
         :param src_directory:
         :param settings:
         """
         self._finalized = False
         self.validate_settings(settings)
-        self.definition_directory: pathlib.Path = getattr(
-            settings, "FHIR_DEFINITION_DIRECTORY", None
+        self.definition_directory: pathlib.Path = typing.cast(
+            pathlib.Path, getattr(settings, "FHIR_DEFINITION_DIRECTORY", None)
         )
-        self.example_directory: pathlib.Path = getattr(
-            settings, "FHIR_EXAMPLE_DIRECTORY", None
+        self.example_directory: pathlib.Path = typing.cast(
+            pathlib.Path, getattr(settings, "FHIR_EXAMPLE_DIRECTORY", None)
         )
-        version_info_file: pathlib.Path = getattr(
-            settings, "FHIR_VERSION_INFO_FILE", None
+        version_info_file: pathlib.Path = typing.cast(
+            pathlib.Path, getattr(settings, "FHIR_VERSION_INFO_FILE", None)
         )
         if (
             self.definition_directory is None
@@ -531,8 +538,13 @@ class FHIRSpec:
         """
         if self._finalized is True:
             raise ValueError("Specification is already been finalized!")
+
+        # self.profiles['meta'].structure.snapshot[-1]
         for key, prof in self.profiles.items():
             prof.finalize()
+            if len(prof.elements_sequences) == 0:
+                for item in prof.structure.snapshot[1:]:
+                    prof.elements_sequences.append(item["id"].split(".")[1])
 
         if self.settings.WRITE_UNITTESTS:
             self.parse_unit_tests()
@@ -551,7 +563,7 @@ class FHIRSpec:
         )
 
     def as_class_name(
-        self, classname: str, parent_name: str = None
+        self, classname: str, parent_name: Optional[str] = None
     ) -> Union[str, None]:
         """
         :param classname:
@@ -580,7 +592,7 @@ class FHIRSpec:
         return classname
 
     def class_name_for_type(
-        self, type_name: str, parent_name: str = None
+        self, type_name: str, parent_name: Optional[str] = None
     ) -> Union[str, None]:
         """
         :param type_name:
@@ -732,7 +744,7 @@ class FHIRVersionInfo:
         self.read_version(info_file)
 
     def read_version(self, filepath: pathlib.Path) -> None:
-        assert filepath.is_file
+        assert filepath.is_file()
         with open(str(filepath), "r", encoding="utf-8") as handle:
             text = handle.read()
             for line in text.split("\n"):
@@ -901,6 +913,7 @@ class FHIRStructureDefinition:
         self._did_finalize: bool = False
         self.fhir_version: Optional[str] = None
         self.fhir_last_updated: Optional[str] = None
+        self.elements_sequences: List[str] = list()
 
         if profile is not None:
             self.parse_profile(profile)
@@ -1217,7 +1230,7 @@ class FHIRStructureDefinitionElement:
             self.children.append(element)
 
     def create_class(
-        self, module: str = None
+        self, module: Optional[str] = None
     ) -> Tuple[Union["FHIRClass", None], Union[None, Sequence["FHIRClass"]]]:
         """Creates a FHIRClass instance from the receiver, returning the
         created class as the first and all inline defined subclasses as the
@@ -1230,29 +1243,31 @@ class FHIRStructureDefinitionElement:
         class_name = self.name_if_class()  # noqa: F841
         subs = []
         cls, did_create = FHIRClass.for_element(self)
+        children = self.children or []
         if did_create:
             LOGGER.debug(f'Created class "{cls.name}"')
             if module is None and self.is_main_profile_element:
                 module = self.profile.spec.as_module_name(cls.name)
             cls.module = module
+            for child in children:
+                cls.add_property_in_sequence(child)
 
         # child classes
-        if self.children is not None:
-            for child in self.children:
-                properties = child.as_properties()
-                if properties is not None:
+        for child in children:
+            properties = child.as_properties()
+            if properties is not None:
 
-                    # collect subclasses
-                    sub, subsubs = child.create_class(module)
-                    if sub is not None:
-                        subs.append(sub)
-                    if subsubs is not None:
-                        subs.extend(subsubs)
+                # collect subclasses
+                sub, subsubs = child.create_class(module)
+                if sub is not None:
+                    subs.append(sub)
+                if subsubs is not None:
+                    subs.extend(subsubs)
 
-                    # add properties to class
-                    if did_create:
-                        for prop in properties:
-                            cls.add_property(prop)
+                # add properties to class
+                if did_create:
+                    for prop in properties:
+                        cls.add_property(prop)
 
         return cls, subs
 
@@ -1473,7 +1488,7 @@ class FHIRStructureDefinitionElementDefinition:
 class FHIRElementType:
     """Representing a type of an element."""
 
-    def __init__(self, type_dict: Dict[str, Any] = None):
+    def __init__(self, type_dict: Optional[Dict[str, Any]] = None):
         self.code: str
         self.profile: Union[None, List[str]] = None
 
@@ -1628,6 +1643,7 @@ class FHIRClass:
         self.short: Optional[str] = None
         self.formal: Optional[str] = None
         self.properties: List[FHIRClassProperty] = list()
+        self.properties_sequence: List[str] = list()
         self.expanded_nonoptionals: Dict[str, List[FHIRClassProperty]] = dict()
         self.class_type = FHIR_CLASS_TYPES.other
         if element.definition:
@@ -1675,6 +1691,34 @@ class FHIRClass:
             else:
                 self.expanded_nonoptionals[prop.one_of_many] = [prop]
 
+    def add_property_in_sequence(self, element: FHIRStructureDefinitionElement) -> None:
+        """ """
+        if element.definition is None:
+            return
+        prop = element.definition.prop_name
+        if prop is None:
+            raise NotImplementedError
+        if prop.endswith("[x]"):
+            for typ in element.definition.types:
+                self.properties_sequence.append(
+                    prop.replace("[x]", typ.code[0].upper() + typ.code[1:])
+                )
+        else:
+            self.properties_sequence.append(prop)
+
+    @property
+    def expanded_properties_sequence(self) -> List[str]:
+        my_properties = self.properties_sequence
+        superclass = self.superclass
+        while True:
+            if superclass is None:
+                break
+            props = superclass.properties_sequence
+            superclass = superclass.superclass
+            if props:
+                my_properties = props + my_properties
+        return my_properties
+
     @property
     def nonexpanded_properties(self) -> List["FHIRClassProperty"]:
         nonexpanded = []
@@ -1741,7 +1785,7 @@ class FHIRClassProperty:
         self,
         element: FHIRStructureDefinitionElement,
         type_obj: FHIRElementType,
-        type_name: str = None,
+        type_name: Optional[str] = None,
     ):
         assert element and type_obj
         # and must be instances of FHIRStructureDefinitionElement and FHIRElementType
@@ -1857,7 +1901,7 @@ class FHIRResourceFile:
 class FHIRUnitTestController:
     """Can create unit tests from example files."""
 
-    def __init__(self, spec: FHIRSpec, settings: Configuration = None):
+    def __init__(self, spec: FHIRSpec, settings: Optional[Configuration] = None):
         """
         :param spec:
         :param settings:
@@ -1933,7 +1977,7 @@ class FHIRUnitTestItem:
         value: Any,
         klass: FHIRClass,
         array_item: bool,
-        enum_item: Dict[str, Any] = None,
+        enum_item: Optional[Dict[str, Any]] = None,
     ):
         assert path
         assert value is not None
@@ -1998,7 +2042,7 @@ class FHIRUnitTest:
         filepath: pathlib.Path,
         content: Dict[str, Any],
         klass: FHIRClass,
-        prefix: str = None,
+        prefix: Optional[str] = None,
     ):
         assert content and klass
         self.controller: FHIRUnitTestController = controller
@@ -2092,7 +2136,9 @@ class FHIRUnitTestCollection:
 
 
 # --*-- Functions
-def resolve_path(string_path: str, parent: pathlib.Path = None) -> pathlib.Path:
+def resolve_path(
+    string_path: str, parent: Optional[pathlib.Path] = None
+) -> pathlib.Path:
     """ """
     if os.path.isabs(string_path):
         return pathlib.Path(string_path)
